@@ -1,13 +1,21 @@
 //! ## Math (//flowstdlib/math)
 //! Math Functions
 
+/// A module with functions to compare data elements
+#[path = "compare/compare.rs"]
+pub mod compare;
 /// A module with a function to add two `Numbers`
+#[path = "add/add.rs"]
 pub mod add;
 /// A module with a function to divide two `Numbers`
+#[path = "divide/divide.rs"]
 pub mod divide;
+/// A module with a function to multiply two `Numbers`
+#[path = "multiply/multiply.rs"]
+pub mod multiply;
 /// A module with a function to subtract two `Numbers`
+#[path = "subtract/subtract.rs"]
 pub mod subtract;
-/// A module with a function to generate a sequence of `Numbers`
-pub mod sequence;
 /// A module with a function to calculate the sqare root of a `Number`
+#[path = "sqrt/sqrt.rs"]
 pub mod sqrt;
\ No newline at end of file
